# -*- coding: utf-8 -*-
"""
@Author: HuangWenBin
@Date: 2023-05-06 09:29:53
@LastEditTime: 2023-05-06 10:11:22
@LastEditors: HuangWenBin
@Description: 
"""
import urllib.parse
import requests
import json
from wallpaper_redis import *

class BDCensorHelper():
    def __init__(self,app_id=23990383) -> None:
        self.__app_id=app_id        
        self.__set_api_key()
        self.__token=self.get_token()

    def __set_api_key(self):
        if self.__app_id==23990383:
            self.__api_key="k3Wl1uk4GueLO6N7LqviYqL9"
            self.__secret_key="o8drefKGeP2AdLkRW3HtfxaCaGiFIRqn"
        elif self.__app_id==24019798:
            self.__api_key="a5aZCkokYnCIeyEpEPaQ9mIy"
            self.__secret_key="WBUaIylvHqOIyX5xQUU716PQV4lPk39d"

    def get_token(self):
        redis_key="BDAIToken:{0}".format(self.__app_id)
        redis_cli=WallpaperRedisHelper()
        token= redis_cli.get(redis_key)
        if token:
            return token
        url = "https://aip.baidubce.com/oauth/2.0/token?grant_type=client_credentials&client_id={0}&client_secret={1}".format(self.__api_key,self.__secret_key)  
        payload = ""
        headers = {
            'Content-Type': 'application/json',
            'Accept': 'application/json'
        }
        
        response = requests.request("POST", url, headers=headers, data=payload)

        if response.status_code==200:
            result_dict=json.loads(response.text)
            token=result_dict["access_token"]
            expires_in=int(result_dict["expires_in"])-60
            if token:
                redis_cli.redis_cli.set(redis_key,token,ex=expires_in)
        
        return token
        
    def img_censor(self,image_url):
        code=0
        message=""
        request_url = "https://aip.baidubce.com/rest/2.0/solution/v1/img_censor/v2/user_defined"
        request_url = request_url + "?access_token=" + self.__token
        headers = {
            'content-type': 'application/x-www-form-urlencoded'
            }
        params="imgUrl={0}&imgType=0".format(image_url)
        response = requests.post(request_url, data=params, headers=headers)
        if response.status_code==200:
            result_dict=json.loads(response.text)
            if not result_dict or not result_dict["conclusion"]=="合规":
                code=0
                message="违规图片"
                if result_dict["data"]:
                    msg_list=[m.get("msg") for m in result_dict["data"]]
                    message=",".join(msg_list)
            else:
                code=1
        else:
            code=0
            message="接口请求失败"
        
        return code,message
    
    def txt_censor(self,word):
        code=0
        message=""
        request_url = "https://aip.baidubce.com/rest/2.0/solution/v1/text_censor/v2/user_defined"
        request_url = request_url + "?access_token=" + self.__token
        headers = {
            'content-type': 'application/x-www-form-urlencoded'
            }
        params="text={0}".format(urllib.parse.quote(word))
        response = requests.post(request_url, data=params, headers=headers)
        if response.status_code==200:
            result_dict=json.loads(response.text)
            if not result_dict or not result_dict["conclusion"]=="合规":
                code=0
                message="违规内容"
                if result_dict["data"]:
                    msg_list=[m.get("msg") for m in result_dict["data"]]
                    message=",".join(msg_list)
            else:
                code=1
        else:
            code=0
            message="接口请求失败"
        
        return code,message

    def video_censor(self,video_url,video_id,video_name):
        code=0
        message=""
        request_url = "https://aip.baidubce.com/rest/2.0/solution/v1/text_censor/v2/user_defined"
        request_url = request_url + "?access_token=" + self.__token
        headers = {
            'content-type': 'application/x-www-form-urlencoded'
            }
        params="name={0}&extId={1}&videoUrl={2}".format(video_name,video_id,video_url)
        response = requests.post(request_url, data=params, headers=headers)
        if response.status_code==200:
            result_dict=json.loads(response.text)
            if not result_dict or not result_dict["conclusion"]=="合规":
                code=0
                message="违规图片"
                if result_dict["data"]:
                    msg_list=[m.get("msg") for m in result_dict["data"]]
                    message=",".join(msg_list)
            else:
                code=1
        else:
            code=0
            message="接口请求失败"
        
        return code,message



# -*- coding: utf-8 -*-
"""
@Author: HuangWenBin
@Date: 2023-03-06 18:18:42
@LastEditTime: 2023-08-30 15:46:59
@LastEditors: 黄文彬 huangwenbin@gao7.com
@Description: 
"""
'''
description: memcached 帮助类
last_editors: HuangWenBin
'''
from seven_framework.memcached import *
from seven_framework import config
import hashlib

class WallpaperMemcacheHelper():
    def __init__(self,depan_key="",cache_key=""):    
        memcache_config=config.get_value("memcached")
        self.host_list=memcache_config["nodes"]
        self.node_num=memcache_config["node_num"]
        self.is_cache=memcache_config["is_cache"]
        self.is_debug=True
        if depan_key:
            self.md5_depan_key,node_index=self.__get_md5_key(key=depan_key)
            self.md5_key=hashlib.md5((depan_key+cache_key).encode("utf-8")).hexdigest()
            self.__mc= MemcachedHelper([self.host_list[node_index]],self.is_debug).memcached_client
        elif cache_key:
            self.md5_key,node_index=self.__get_md5_key(key=cache_key)
            self.__mc= MemcachedHelper([self.host_list[node_index]],self.is_debug).memcached_client
        else:
            self.__mc=None

        
    def m_set(self,value,time=60*30):
        '''
        description: 设置单个缓存
        param value 缓存值
        param time 过期时间(单位：秒)
        last_editors: HuangWenBin
        '''
        if not self.is_cache:
            return
        self.__mc.set(key=self.md5_key,val=value,time=time)

    def m_get(self):
        '''
        description: 获取单个缓存
        return 缓存值
        last_editors: HuangWenBin
        '''
        if not self.is_cache:
            return None
        return self.__mc.get(key=self.md5_key)

    def m_depan_set(self,value,time=60*30):
        '''
        description: 设置依赖缓存
        param value 缓存值
        param time 过期时间(单位：秒)
        last_editors: HuangWenBin
        '''
        if not self.is_cache:
            return
        md5_key_in_depan_list=[]
        md5_depan_key_value= self.__mc.get(key=self.md5_depan_key)
        if md5_depan_key_value:
            md5_key_in_depan_list=list(md5_depan_key_value)
            md5_key_in_depan_list.append(self.md5_key)
            md5_key_in_depan_list=list(set(md5_key_in_depan_list))            
        else:
            md5_key_in_depan_list.append(self.md5_key)
        
        self.__mc.set(key=self.md5_depan_key,val=md5_key_in_depan_list,time=time)
        self.__mc.set(key=self.md5_key,val=value,time=time)

    def m_depan_get(self):
        '''
        description: 获取依赖缓存值
        return 缓存值
        last_editors: HuangWenBin
        '''
        if not self.is_cache:
            return None
        return self.__mc.get(key=self.md5_key)

    def m_remove(self):
        '''
        description: 删除单个缓存
        return 删除缓存数量
        last_editors: HuangWenBin
        '''
        if not self.is_cache:
            return 0
        return self.__mc.delete(self.md5_key)

    def m_depan_remove_one(self):
        '''
        description: 删除依赖键下所有缓存
        return 删除缓存数量
        last_editors: HuangWenBin
        '''
        if not self.is_cache:
            return 0
        md5_key_in_depan_list=[]
        md5_depan_key_value= self.__mc.get(key=self.md5_depan_key)
        if md5_depan_key_value:
            md5_key_in_depan_list=list(md5_depan_key_value)
            if self.md5_key in md5_key_in_depan_list:
                md5_key_in_depan_list.remove(self.md5_key)
            self.__mc.set(key=self.md5_depan_key,val=md5_key_in_depan_list,time=1800)
            self.__mc.delete(key=self.md5_key)
            return 1
        
        return 0
    
    def m_depan_remove(self):
        '''
        description: 删除依赖键下所有缓存
        return 删除缓存数量
        last_editors: HuangWenBin
        '''
        if not self.is_cache:
            return 0
        md5_key_in_depan_list=[]
        md5_depan_key_value= self.__mc.get(key=self.md5_depan_key)
        if md5_depan_key_value:
            md5_key_in_depan_list=list(md5_depan_key_value)
            result=self.__mc.delete_multi(keys=md5_key_in_depan_list)
            if result:
                self.__mc.delete(key=self.md5_depan_key)
            return result
        
        return 0

    def __get_md5_key(self,key):
        '''
        description: 获取缓存键值名称16进制加密值以及缓存节点索引
        param key 缓存名称
        return 16进制加密值以及缓存节点索引
        last_editors: HuangWenBin
        '''
        md5_key=hashlib.md5(key.encode("utf-8")).hexdigest()
        long_md5_key=int(md5_key,16)
        node_index=long_md5_key%self.node_num
        return md5_key,node_index




# -*- coding: utf-8 -*-
"""
@Author: HuangWenBin
@Date: 2023-04-07 09:51:48
@LastEditTime: 2023-04-27 13:45:11
@LastEditors: HuangWenBin
@Description: 
"""

from seven_framework import config
from seven_framework.redis import *

class WallpaperRedisHelper():
    def __init__(self,config_key="redis"):
        host = config.get_value(config_key)["host"]
        port = config.get_value(config_key)["port"]
        db = config.get_value(config_key)["db"]
        password = config.get_value(config_key)["password"]
        self.redis_cli = RedisHelper.redis_init(host, port, db, password)


    def get(self,key):
        value=self.redis_cli.get(key)
        if value:
            return value.decode("utf-8")
        return ""
    
    def mget(self,keys:list):
        value_list=self.redis_cli.mget(keys)        
        if value_list:
            return [v.decode("utf-8") for v in value_list]
        return []

    def hget(self,name,key):
        value=self.redis_cli.hget(name,key)
        if value:
            return value.decode("utf-8")
        
        return ""
    
    def hmget(self,keys:list):
        value_list=self.redis_cli.hmget(keys)        
        if value_list:
            return [v.decode("utf-8") for v in value_list]
        return []
    
    def hincrby(self,name,key,amount=1):
        return self.redis_cli.hincrby(name,key,amount)

    def hsetnx(self,name,key,value):
        return self.redis_cli.hsetnx(name,key,value)
    
    def lpop(self,name):
        return self.redis_cli.lpop(name).decode()
    
    def llen(self,name):
        return self.redis_cli.llen(name)
    
    def expireat(self, name, when, nx: bool = False, xx: bool = False, gt: bool = False, lt: bool = False):
        return self.redis_cli.expireat(name,when,nx,xx,gt,lt)
    

if __name__=="__main__":
    redis_cli=WallpaperRedisHelper()
    redis_cli.redis_cli.set("test","test")
    value=redis_cli.redis_cli.get("test")
    print(type(value))
    print(value)


# -*- coding: utf-8 -*-
"""
@Author: HuangWenBin
@Date: 2023-02-24 11:30:45
@LastEditTime: 2023-05-11 15:53:57
@LastEditors: HuangWenBin
@Description: 
"""

from Crypto.Cipher import DES
from seven_framework import config
import base64

class app_des_encrypt():
    def __init__(self):
        self.des_secret_key=config.get_value("des_encrypt_key")

    def des_encrypt(self,content):
        content=content.encode()
        padding_len = DES.block_size - (len(content) % DES.block_size)
        padded_plaintext = content + bytes([padding_len] * padding_len)

        des_obj = DES.new(self.des_secret_key.encode(), DES.MODE_CBC, self.des_secret_key.encode())
        secret_bytes = des_obj.encrypt(padded_plaintext)    
        return base64.b64encode(secret_bytes)

    def des_decrypt(self, content):
        secret_bytes = base64.b64decode(content)
        des_obj = DES.new(self.des_secret_key.encode(), DES.MODE_CBC, self.des_secret_key.encode())
        decrypted_padded_plaintext = des_obj.decrypt(secret_bytes)

        # 移除填充
        if len(decrypted_padded_plaintext) > 0:
            padding_len = decrypted_padded_plaintext[-1]
            decrypted_plaintext = decrypted_padded_plaintext[:-padding_len]
        else:
            decrypted_plaintext = decrypted_padded_plaintext

        return decrypted_plaintext


from elasticsearch import Elasticsearch
from seven_framework import config
import json

class WallpaperElasticSearch():
    def __init__(self,index_name):
        """
        :description: es_client初始化
        :param index_name 索引名称
        :last_editors: HuangWenBin
        """
        hostAddress=config.get_value("es")["host"]
        self.index_name=index_name
        self.doc_type_name="_doc"
        self.es=Elasticsearch(hostAddress,sniffer_timeout=600)

    def es_index_init(self,es_model_config_path):   
        """
        :description: 索引映射初始化
        :param es_model_config_path 索引model文件路径
        :return 
        :last_editors: HuangWenBin
        """
        with open(es_model_config_path) as json_file:
            es_body=json.load(json_file)
        if es_body:
            result= self.es.indices.create(self.index_name,body=es_body)
            return result
        else:
            result={"code":"error","msg":"es_body is empty"}

    def es_querypage(self,param_body,param_size,param_from_):
        """
        :description: 读取分页数据
        :param param_body 查询语句
        :param param_size 读取数量
        :param param_from_ 读取起始位置
        :return dic_list 字段列表 count 数量 is_last_page 是否最后一页
        :last_editors: HuangWenBin
        """
        data= self.es.search(index=self.index_name,doc_type=self.doc_type_name, body=param_body,size=param_size,from_=param_from_)
        dic_list=[]
        count=0
        for item in data['hits']['hits']:
            dic_list.append(item['_source'])
        count=data['hits']['total']['value']
        isLastPage=True
        if int(count)>param_from_+param_size:
            isLastPage=False
        
        return {"dic_list":dic_list,"count":count,"is_last_page":isLastPage}

    def es_querycount(self,param_body):
        """
        :description: 根据条件查询文档数量
        :param {*} param_body 查询语句
        :return {*}count 数量
        :last_editors: HuangWenBin
        """
        count= self.es.count(body=param_body,index=self.index_name,doc_type=self.doc_type_name)
        #print(count)
        return count
    
    def es_queryrecord(self,key_name,key_value):
        """
        :description: 
        :param key_name 字段名
        :param key_value 字段值
        :return dict实体
        :last_editors: HuangWenBin
        """
        es_body={"query":{"term":{str(key_name):key_value}}}
        data= self.es.search(index=self.index_name,doc_type=self.doc_type_name,body=es_body,size=1,from_=0)
        dic_list=[]
        for item in data['hits']['hits']:
            dic_list.append(item['_source'])
        if len(dic_list)>0:
            return dic_list[0]
        return ""

    def es_update(self,key_id,**param_dict):
        """
        @description: 根据id更新数据
        @param key_id:主键id
        @param param_dict: 更新字段，字典传值
        @return: 更新成功即为True 失败则为False
        @last_editors: HuangWenBin
        """
        es_body={"doc":param_dict}
        result= self.es.update(id=key_id, index=self.index_name,doc_type=self.doc_type_name,body=es_body)
        return result

    def es_update_by_query(self,es_body):
        """
        :description: 根据条件更新数据表
        :param es_body 更新语句
        :return :更新成功即为True 失败则为False
        :last_editors: HuangWenBin
        """
        result= self.es.update_by_query(index=self.index_name,doc_type=self.doc_type_name,body=es_body)
        return result

    def es_add(self,id,es_body):
        """
        :description: 添加文档
        :param id 主键id
        :param es_body 文档内容
        :return 
        :last_editors: HuangWenBin
        """
        result=self.es.create(index=self.index_name,doc_type=self.doc_type_name,id=id,body=es_body)
        return result
    
    def es_delete_by_query(self,es_body):
        """
        :description: 根据条件删除数据表
        :param es_body 删除语句
        :return 成功即为True 失败则为False
        :last_editors: HuangWenBin
        """
        result= self.es.delete_by_query(index=self.index_name,doc_type=self.doc_type_name,body=es_body)
        return result
        
    def es_delete_by_id(self,id):
        """
        :description: 根据主键id删除记录
        :param 主键id
        :return 成功即为True 失败则为False
        :last_editors: HuangWenBin
        """
        result= self.es.delete(id)
        return result



from setuptools import setup

setup(
    name='bizhi-framework',
    version='1.0.11',
    author='huangwenbin',
    description='bizhi project base framework',
    packages=['bizhi_framework','bizhi_framework.bizhi_web'],
    install_requires=[
        'seven-framework>=1.1.32'
    ],
    password='pypi-AgEIcHlwaS5vcmcCJGMzODEzYWZhLTUyY2EtNDU5OC1iZWNkLTJhNDgxNWViYzE2OQACKlszLCI3N2M3MWVlMy05NGQwLTRiZDEtYWI3YS00OTQ1ZTdlNmQwNzciXQAABiDFZYU2iKKyTt3EdZykU7KO7YnNwiPujkQ-q8m1q8Kvrg'
)

#python setup.py sdist bdist_wheel
#twine upload --username __token__ --password pypi-AgEIcHlwaS5vcmcCJGMzODEzYWZhLTUyY2EtNDU5OC1iZWNkLTJhNDgxNWViYzE2OQACKlszLCI3N2M3MWVlMy05NGQwLTRiZDEtYWI3YS00OTQ1ZTdlNmQwNzciXQAABiDFZYU2iKKyTt3EdZykU7KO7YnNwiPujkQ-q8m1q8Kvrg dist/*



from seven_framework.web_tornado.base_handler.base_api_handler import *
from app_encrypt import *

class WallpaperBaseHandler(BaseApiHandler):
    def __init__(self, *argc, **argkw):
        """
        :Description: 初始化
        :last_editors: ChenXiaolei
        """
        super(BaseApiHandler, self).__init__(*argc, **argkw)

    def get_useragent(self):
        """
        @description:获取app客户端头部信息
        @return：返回头部信息
        @last_editors: HuangWenBin
        """
        user_agent= UserAgentInfo()
        dic_header=self.request.headers
        if "User-Agent1" not in dic_header:
            return user_agent
        user_agent1=dic_header._dict["User-Agent1"]
        if user_agent1.startswith("2"):
            user_agent1=user_agent1[1:]
        #dict_useragent={}
        decrypt=app_des_encrypt()
        user_agent1=decrypt.des_decrypt(user_agent1)
        list_str = str.split(CodingHelper.url_decode(user_agent1.decode("unicode_escape")), "&")

        for item in list_str:
            key,value=item.split("=")
            if hasattr(user_agent, key):
                if key in["pid","pt","ch","ver","adolescent","login"]:
                    if value:
                        setattr(user_agent, key, int(value))
                    else:
                        setattr(user_agent, key, 0)
                else:
                    setattr(user_agent, key, value)

        user_agent.userip=self.get_remote_ip()
        return user_agent

    def get_request_param(self, param_name, default=""):
        if not param_name in self.request_params:
            return default
        param_ret=self.request_params[param_name]
        return param_ret
    
    def get_request_param_int(self, param_name, default=0):
        param_ret=self.get_request_param(param_name,"0")
        if not param_ret or param_ret == "0":
            param_ret = default
        return int(param_ret)
    
    def get_param_int(self,param_name,default=0):
        param_value= self.get_param(param_name)
        if param_value:
            return default
        return int(param_value)

    def get_url_param(self,url,param_name):
        url=CodingHelper.url_decode(url)
        list_str = str.split(url,"&")
        for item in list_str:
            kv=item.split("=")
            if len(kv)==2 and kv[0]==param_name:
                return kv[1]        
        return ""



class UserAgentInfo():
    def __init__(self):
        self.ch="0"
        self.simidfa=""
        self.lang=""
        self.adtid=""
        self.mtype=""
        self.nickname=""
        self.openid=""
        self.osver=""
        self.adolescent=""
        self.uidsign=""
        self.g7udid=""
        self.token=""
        self.ver=0
        self.idfv=""
        self.login=0
        self.pid=0
        self.sdkver="0"
        self.pt=0
        self.screen=""
        self.userip=""
        self.ua=""
        self.net=""